#
# spec file for package python-boost-histogram
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
# No numpy for python 3.6 on TW
%define skip_python36 1
# py2 not supported
%define skip_python2 1
%define modname boost_histogram
Name:           python-boost-histogram
Version:        1.4.0
Release:        1.1
Summary:        The Boost::Histogram Python wrapper
License:        BSD-3-Clause
URL:            https://github.com/scikit-hep/boost-histogram
Source:         https://files.pythonhosted.org/packages/source/b/boost-histogram/boost_histogram-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
%if 0%{?suse_version} < 1550
BuildRequires:  python3-dataclasses
%endif
# SECTION test requirements
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pytest-benchmark}
BuildRequires:  %{python_module pytest}
# /SECTION
Requires:       python-numpy
%python_subpackages

%description
Python bindings for Boost::Histogram (source), a C++14 library. This is one of
the fastest libraries for histogramming, while still providing the power of a
full histogram object.

%prep
%setup -q -n boost_histogram-%{version}

%build
export CFLAGS="%{optflags}"
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
# On i586 this test fails for unknown reason, see https://github.com/scikit-hep/boost-histogram/issues/598
%ifarch %ix86
%pytest_arch -k 'not test_log_transform'
%else
%pytest_arch
%endif

%files %{python_files}
%{python_sitearch}/%{modname}/
%{python_sitearch}/%{modname}-%{version}-py%{python_version}.egg-info/

%changelog
* Fri Oct 13 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.4.0:
  * `overflow=False` is now supported for `IntCategory` and
    `StrCategory` [gh#scikit-hep/boost-histogram#883].
  * Updated Boost to 1.82. The upper limit on Regular axes without
    overflow is now inclusive like NumPy
    [gh#scikit-hep/boost-histogram#802].
  * Produce more detailed error messages on C++ errors
    [gh#scikit-hep/boost-histogram#848].
  * Include `-latomic` on `armv7l`
    [gh#scikit-hep/boost-histogram#823].
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to v1.3.2:
  * Added storage_type() as public API #781, with pending deprecation for
    _storage_type. #786 #790
  * Better errors generated for missing or incorrect sample to mean storage.
    [#782]
  * Better error message when views are set with an incompatible array. #794
  * Patch broken sum with fully empty (0 bin) axis. #718
  * Fix zero range bh.numpy.histogram to match numpy.histogram behavior.
    [#721]
  * Avoid triggering __init__ when copying (better support for subclasses
    with custom init's). #759
  * IntCategory now supports numbers larger than 224 (now 253). #792
  * Pick a subset now supported inside a larger expression. #793
  * Backend and docs
  * Minor optimizations for UFuncs. #771
  * Added Python 3.11 wheels. #789
  * Include PyPy 3.9 binary wheels. #730
  * Using pybind11 2.10 #767
  * Explicit reset() documentation. #783
  * Minor cleanup and further removal of a little Python 2 back-compat code.
  * Warnings have better stacklevel settings.
* Thu Jun 23 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 1.3.1:
  Bug fixes
  * Fixed regression with invalid .project input causing segfaults. #708
  * Minor skips for specific tests on ppc64le, primarily for a NumPy bug. #707
  * Avoid using EH for program control, better on Pyodide. #709
  * Fix regression with exact float not being accepted for .index for IntCategory
    in 1.3.0. Add hist nox session to check downstream (manually for the
    moment). #710
- Update to 1.3.0:
  User changes
  * PyPy 3.8 now supported with binary wheels. #677
  * The GIL is released a little more often now. #662
  * AxesTuple does not allow construction of non-axes. #680
  * KeyError is now thrown when accessing a non-existent item in a Category Axis #689
  * WeightedViews now support np.cumsum #699
  Bug fixes
  * Fixed WeightedMean storages producing NaN for .variances() #695
  * Modify local include slightly to enable WebAssembly compilation in Pyodide #702
  Developer changes
  * Use PyLint in CI to check for some style issues #690
  * Developer (CMake) installs no longer require toml #698
- Update to 1.2.1:
  User changes
  * musllinux wheels now provided along with manylinux #656
  Bug fixes
  * Fixed single-element negative growth fill #654
  Developer changes
  * No longer require Docker for clang-format, runs online too #610
  * Using pybind11 2.8.0 #658
- Update to 1.2.0:
  User changes
  * Python 3.10 officially supported, with wheels.
  * Support subtraction on histograms #636
  * Integer histograms are now signed #636
  Bug fixes
  * Support custom setters on AxesTuple subclasses. #627
  * Faster picking if slices are not also used #645 or if they are #648 (1000x or more in some cases)
  * Throw an error when an AxesTuple setter is the wrong length (inspired by zip strict in Python 3.10) #627
  * Fix error thrown on comparison with axis and non-axis object #631
  * Static typing no longer thinks storage= is required #604
  Developer changes
  * Support NumPy 1.21 for static type checking #625
  * Use newer Boost 1.77 and Boost.Histogram 1.77+1 #594
  * Provide nox support #647
- Update to 1.1.0:
  User changes
  * Experimentally support list selection on categorical axes #577
  * Support Python 3.8 on Apple Silicon #600
  * Scaling and addition with a scalar affect flow bins too #580
  * Change sum_of_deltas_squared to _sum_of_deltas_squared (was an implementation detail) #602
  Bug fixes
  * Fix "picking" on a flow bin #576
  * Better error message on getattr #596
  Developer changes
  * Test on Python 3.10 beta releases #600
  * Provide a CMakeLists for quick standalone Boost.Histogram C++ experiments #591
  * Adding logging with PyTest failure output #575
* Sat Jul  3 2021 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
